@@ -2,6 +2,7 @@ from django.views import View
 from django.utils.translation import gettext_lazy as _
 from badi_utils.dynamic import DynamicListView
 from badi_wallet.action import MERCHANT, ZP_API_VERIFY, ZPBankAction
+from badi_wallet.filter import TransactionFilter
 from badi_wallet.models import Transaction, BankTransaction
 
 
@@ -17,6 +18,14 @@ class AdminTransActionsView(DynamicListView):
     template_name = 'transaction/all_transaction_list.html'
 
 
+class ReportTransActionsView(DynamicListView):
+    model = Transaction
+    template_name = 'transaction/all_transaction_report.html'
+    extra_context = {
+        'form': TransactionFilter().form
+    }
+
+
 class ZPVerifyTransActionsView(View):
     bankError = _("The operation encountered an error. Please try again."
                   " If the amount is deducted from your account, it will be returned to your account within 72 hours.")
